@@ -24,7 +24,7 @@ THE SOFTWARE.
 
 module contains function for generating preview and histogram:
 - preview_histogram - preview histogram
-- preview_wand - for preview pictures 
+- preview_wand - for preview pictures
 """
 
 import os
@@ -32,7 +32,6 @@ import tempfile
 
 try:
     from wand.drawing import Drawing
-    from wand.image import Image
 except:
     print(" ImageMagick or Wand-py not found")
 
@@ -40,8 +39,9 @@ import common
 import convert_wand
 import log
 import magick
+import mswindows
 
-def preview_histogram(file_in, gm_or_im):
+def preview_histogram(file_in):
     """
     histogram generation
     file_in - fullname image file
@@ -50,10 +50,12 @@ def preview_histogram(file_in, gm_or_im):
     return: fullname of histogram
     """
 
-    cmd_magick = gm_or_im + "convert"
-    file_histogram = os.path.join(tempfile.gettempdir(),
-                                  "fotokilof_" + os.getlogin() \
-                                  + "_histogram.ppm")
+    if mswindows.windows():
+        cmd_magick = "magick.exe convert"
+    else:
+        cmd_magick = "convert"
+
+    file_histogram = os.path.join(tempfile.gettempdir(), "fotokilof_histogram.ppm")
     command = " -define histogram:unique-colors=false histogram:"
     command = " histogram:"
 
@@ -67,7 +69,7 @@ def preview_histogram(file_in, gm_or_im):
     return 'none'
 
 
-def preview_wand(file_in, size, coord):
+def preview_wand(file_in, size, coord=""):
     """
     preview generation by Wand
     file_in - fullname image file
@@ -79,6 +81,12 @@ def preview_wand(file_in, size, coord):
     - file size
     - width and height
     """
+    result = {'filename': None,
+            'size': '0',
+            'width': '0',
+            'height': '0',
+            'preview_width': '0',
+            'preview_height': '0'}
     if file_in is not None:
         if os.path.isfile(file_in):
             filesize = common.humansize(os.path.getsize(file_in))
@@ -88,7 +96,7 @@ def preview_wand(file_in, size, coord):
             height = clone.height
 
             convert_wand.resize(clone, str(size) + "x" + str(size))
-            
+
             # write crop if coordinates are given
             if len(coord) == 4 :
                 with Drawing() as draw:
@@ -103,14 +111,18 @@ def preview_wand(file_in, size, coord):
                     draw.line(right_top, right_bottom)
                     draw(clone)
             clone.convert('ppm')
-            file_preview = os.path.join(tempfile.gettempdir(),
-                                            "fotokilof_" + os.getlogin() \
-                                            + "_preview.ppm")
+            preview_width = clone.width
+            preview_height = clone.height
+            file_preview = os.path.join(tempfile.gettempdir(), "fotokilof_preview.ppm")
             convert_wand.save_close_clone(clone, file_preview, 0)
-            result = {'filename': file_preview,
+            result = {'filename': common.spacja(file_preview),
                           'size': filesize,
                           'width': str(width),
-                          'height': str(height)}
-            return result
+                          'height': str(height),
+                          'preview_width': str(preview_width),
+                          'preview_height': str(preview_height)}
+
+
+    return result
 
 # EOF
